"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bigInt = require("big-integer");
const ontology_ts_crypto_1 = require("ontology-ts-crypto");
const ontology_ts_test_1 = require("ontology-ts-test");
// tslint:disable:object-literal-key-quotes
class Tooler {
    addressToHex(address) {
        return ontology_ts_crypto_1.Address.fromBase58(address)
            .toArray()
            .toString('hex');
    }
    str2hex(str) {
        return new Buffer(str).toString('hex');
    }
    hexReverse(hex) {
        return ontology_ts_test_1.reverseBuffer(new Buffer(hex, 'hex')).toString('hex');
    }
    num2hex(num) {
        return ontology_ts_crypto_1.Serialize.bigIntToBytes(bigInt(num)).toString('hex');
    }
    randomPrivateKey() {
        return ontology_ts_crypto_1.PrivateKey.random().key.toString('hex');
    }
    async decryptPrivateKey(key, address, salt, n = '16384', password) {
        const account = ontology_ts_crypto_1.Account.deserializeJson({
            address,
            algorithm: 'ECDSA',
            'enc-alg': 'aes-256-gcm',
            hash: 'sha256',
            isDefault: true,
            key,
            label: 'label',
            lock: false,
            parameters: {
                curve: 'P-256'
            },
            publicKey: '03f631f975560afc7bf47902064838826ec67794ddcdbcc6f0a9c7b91fc8502583',
            salt,
            signatureScheme: 'SHA256withECDSA'
        }, {
            r: 8,
            p: 8,
            keyLength: 64,
            N: Number(n)
        });
        const sk = await account.decryptKey(password);
        return sk.key.toString('hex');
    }
}
exports.Tooler = Tooler;
//# sourceMappingURL=tooler.js.map