"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const punicaException_1 = require("../exception/punicaException");
function removeFileIfExists(p) {
    if (fs.statSync(p).isFile()) {
        fs.unlinkSync(p);
    }
}
exports.removeFileIfExists = removeFileIfExists;
function ensureRemoveDirIfExists(p) {
    if (fs.existsSync(p)) {
        fs.readdirSync(p).forEach((file, index) => {
            const curPath = p + '/' + file;
            if (fs.lstatSync(curPath).isDirectory()) {
                // recurse
                ensureRemoveDirIfExists(curPath);
            }
            else {
                // delete file
                fs.unlinkSync(curPath);
            }
        });
        fs.rmdirSync(p);
    }
}
exports.ensureRemoveDirIfExists = ensureRemoveDirIfExists;
function ensureDirExist(p) {
    if (fs.existsSync(p)) {
        if (fs.statSync(p).isFile()) {
            throw new Error(`Path ${p} is a file. Should be a directory.`);
        }
    }
    else {
        fs.mkdirSync(p, { recursive: true });
    }
}
exports.ensureDirExist = ensureDirExist;
function readAvm(avmDirPath, avmFileName) {
    if (!fs.statSync(avmDirPath).isDirectory) {
        throw punicaException_1.directoryError();
    }
    let avm;
    if (avmFileName !== undefined) {
        const avmFilePath = path.join(avmDirPath, avmFileName);
        if (!fs.existsSync(avmFilePath)) {
            throw punicaException_1.otherError(`${avmFilePath} not exist`);
        }
        avm = readAvmInternal(avmFilePath);
        return [avm, avmFileName];
    }
    else {
        const dirList = fs.readdirSync(avmDirPath);
        avm = new Buffer('');
        for (const file of dirList) {
            const splitPath = path.parse(file);
            if ((pathRoot(splitPath) === avmFileName || avmFileName === undefined) && splitPath.ext === '.avm') {
                avmFileName = file;
                const avmPath = path.join(avmDirPath, file);
                avm = readAvmInternal(avmPath);
                return [avm, avmFileName];
            }
        }
        throw punicaException_1.avmFileEmpty();
    }
}
exports.readAvm = readAvm;
function readAbi(abiDirPath, abiFileName) {
    if (!fs.statSync(abiDirPath).isDirectory()) {
        throw punicaException_1.otherError('Build folder does not exist, please compile first.');
    }
    const abiFilePath = path.join(abiDirPath, abiFileName);
    if (!fs.existsSync(abiFilePath)) {
        throw punicaException_1.otherError('ABI confi file does not exist');
    }
    const f = fs.readFileSync(abiFilePath, 'utf8');
    return JSON.parse(f);
}
exports.readAbi = readAbi;
function readAvmInternal(p) {
    const codeBuffer = fs.readFileSync(p);
    const codeString = codeBuffer.toString();
    return new Buffer(codeString, 'hex');
}
function pathRoot(splitPath) {
    return path.join(splitPath.dir, splitPath.name);
}
//# sourceMappingURL=fileSystem.js.map